Package: ineptr2
Title: Wrapper for Statistics Portugal API
Version: 0.3.1
Authors@R: 
    person("Carlos", "Matos", , "carlosmdmatos@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-1134-0396"))
Description: An R6-based client to facilitate interaction with the Statistics
    Portugal (Instituto Nacional de Estatistica - INE) API
    (<https://www.ine.pt/xportal/xmain?xpid=INE&xpgid=ine_api&INST=322751522&xlang=en>).
License: MIT + file LICENSE
URL: https://c-matos.github.io/ineptr2/,
        https://github.com/c-matos/ineptr2
BugReports: https://github.com/c-matos/ineptr2/issues
Imports: httr2, jsonlite, R6, rlang, xml2
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), withr
VignetteBuilder: knitr
Depends: R (>= 4.1.0)
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-30 22:28:52 UTC; carlmatos
Author: Carlos Matos [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-1134-0396>)
Maintainer: Carlos Matos <carlosmdmatos@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-01 18:50:02 UTC
Built: R 4.5.2; ; 2026-05-01 20:05:56 UTC; unix
