% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{is_filter_subset}
\alias{is_filter_subset}
\title{Check if current dimension filters are a subset of cached filters}
\usage{
is_filter_subset(current, cached)
}
\arguments{
\item{current}{Named list of current dimension filters (normalized)}

\item{cached}{Named list of cached dimension filters (normalized)}
}
\value{
TRUE if every value in current is available in cached
}
\description{
Check if current dimension filters are a subset of cached filters
}
\keyword{internal}
