% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{records_to_df}
\alias{records_to_df}
\title{Convert a list of named lists to a data.frame}
\usage{
records_to_df(records)
}
\arguments{
\item{records}{A list of named lists with consistent field names.}
}
\value{
A data.frame.
}
\description{
Handles NULL values by replacing them with NA, unlike
\code{as.data.frame} which silently drops NULL elements.
}
\keyword{internal}
