% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ineptr2-package.R
\docType{package}
\name{ineptr2-package}
\alias{ineptr2}
\alias{ineptr2-package}
\title{ineptr2: Wrapper for Statistics Portugal API}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

An R6-based client to facilitate interaction with the Statistics Portugal (Instituto Nacional de Estatistica - INE) API (\url{https://www.ine.pt/xportal/xmain?xpid=INE&xpgid=ine_api&INST=322751522&xlang=en}).
}
\seealso{
Useful links:
\itemize{
  \item \url{https://c-matos.github.io/ineptr2/}
  \item \url{https://github.com/c-matos/ineptr2}
  \item Report bugs at \url{https://github.com/c-matos/ineptr2/issues}
}

}
\author{
\strong{Maintainer}: Carlos Matos \email{carlosmdmatos@gmail.com} (\href{https://orcid.org/0000-0003-1134-0396}{ORCID}) [copyright holder]

}
\keyword{internal}
